==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/AzureActiveDirectoryValidationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active Directory token validation flow.
 * @property allowedAudiences The list of audiences that can make successful authentication/authorization requests.
 * @property defaultAuthorizationPolicy The configuration settings of the default authorization policy.
 * @property jwtClaimChecks The configuration settings of the checks that should be made while validating the JWT Claims.
 */
public data class AzureActiveDirectoryValidationArgs(
    public val allowedAudiences: Output<List<String>>? = null,
    public val defaultAuthorizationPolicy: Output<DefaultAuthorizationPolicyArgs>? = null,
    public val jwtClaimChecks: Output<JwtClaimChecksArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs =
        com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs.builder()
            .allowedAudiences(allowedAudiences?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .defaultAuthorizationPolicy(
                defaultAuthorizationPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .jwtClaimChecks(
                jwtClaimChecks?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureActiveDirectoryValidationArgs].
 */
@PulumiTagMarker
public class AzureActiveDirectoryValidationArgsBuilder internal constructor() {
    private var allowedAudiences: Output<List<String>>? = null

    private var defaultAuthorizationPolicy: Output<DefaultAuthorizationPolicyArgs>? = null

    private var jwtClaimChecks: Output<JwtClaimChecksArgs>? = null

    /**
     * @param value The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("umcmxahatgrddkoc")
    public suspend fun allowedAudiences(`value`: Output<List<String>>) {
        this.allowedAudiences = value
    }

    @JvmName("owvgieggqcaurchf")
    public suspend fun allowedAudiences(vararg values: Output<String>) {
        this.allowedAudiences = Output.all(values.asList())
    }

    /**
     * @param values The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("xpmflsawlmiypmwf")
    public suspend fun allowedAudiences(values: List<Output<String>>) {
        this.allowedAudiences = Output.all(values)
    }

    /**
     * @param value The configuration settings of the default authorization policy.
     */
    @JvmName("lxqacbrnwjdfyniu")
    public suspend fun defaultAuthorizationPolicy(`value`: Output<DefaultAuthorizationPolicyArgs>) {
        this.defaultAuthorizationPolicy = value
    }

    /**
     * @param value The configuration settings of the checks that should be made while validating the JWT Claims.
     */
    @JvmName("vgjkdfwluugogsul")
    public suspend fun jwtClaimChecks(`value`: Output<JwtClaimChecksArgs>) {
        this.jwtClaimChecks = value
    }

    /**
     * @param value The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("xfbbhltbgofcwnui")
    public suspend fun allowedAudiences(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedAudiences = mapped
    }

    /**
     * @param values The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("bdvophlottgldxar")
    public suspend fun allowedAudiences(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedAudiences = mapped
    }

    /**
     * @param value The configuration settings of the default authorization policy.
     */
    @JvmName("hnprexgfbudqewgc")
    public suspend fun defaultAuthorizationPolicy(`value`: DefaultAuthorizationPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultAuthorizationPolicy = mapped
    }

    /**
     * @param argument The configuration settings of the default authorization policy.
     */
    @JvmName("usvttscifvpvsoya")
    public suspend
    fun defaultAuthorizationPolicy(argument: suspend DefaultAuthorizationPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultAuthorizationPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.defaultAuthorizationPolicy = mapped
    }

    /**
     * @param value The configuration settings of the checks that should be made while validating the JWT Claims.
     */
    @JvmName("iientqpdheiyjvjv")
    public suspend fun jwtClaimChecks(`value`: JwtClaimChecksArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.jwtClaimChecks = mapped
    }

    /**
     * @param argument The configuration settings of the checks that should be made while validating the JWT Claims.
     */
    @JvmName("iptgwmhxlqxejkma")
    public suspend fun jwtClaimChecks(argument: suspend JwtClaimChecksArgsBuilder.() -> Unit) {
        val toBeMapped = JwtClaimChecksArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.jwtClaimChecks = mapped
    }

    internal fun build(): AzureActiveDirectoryValidationArgs = AzureActiveDirectoryValidationArgs(
        allowedAudiences = allowedAudiences,
        defaultAuthorizationPolicy = defaultAuthorizationPolicy,
        jwtClaimChecks = jwtClaimChecks,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/AzureActiveDirectoryValidationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The configuration settings of the Azure Active Directory token validation flow.
 * @property allowedAudiences The list of audiences that can make successful authentication/authorization requests.
 * @property defaultAuthorizationPolicy The configuration settings of the default authorization policy.
 * @property jwtClaimChecks The configuration settings of the checks that should be made while validating the JWT Claims.
 */
public data class AzureActiveDirectoryValidationArgs(
    public val allowedAudiences: Output<List<String>>? = null,
    public val defaultAuthorizationPolicy: Output<DefaultAuthorizationPolicyArgs>? = null,
    public val jwtClaimChecks: Output<JwtClaimChecksArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs =
        com.pulumi.azurenative.app.inputs.AzureActiveDirectoryValidationArgs.builder()
            .allowedAudiences(allowedAudiences?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .defaultAuthorizationPolicy(
                defaultAuthorizationPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .jwtClaimChecks(
                jwtClaimChecks?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [AzureActiveDirectoryValidationArgs].
 */
@PulumiTagMarker
public class AzureActiveDirectoryValidationArgsBuilder internal constructor() {
    private var allowedAudiences: Output<List<String>>? = null

    private var defaultAuthorizationPolicy: Output<DefaultAuthorizationPolicyArgs>? = null

    private var jwtClaimChecks: Output<JwtClaimChecksArgs>? = null

    /**
     * @param value The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("ttygiasrcmoqctyj")
    public suspend fun allowedAudiences(`value`: Output<List<String>>) {
        this.allowedAudiences = value
    }

    @JvmName("cpehlidariddoeyo")
    public suspend fun allowedAudiences(vararg values: Output<String>) {
        this.allowedAudiences = Output.all(values.asList())
    }

    /**
     * @param values The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("kfesiquupneemlyk")
    public suspend fun allowedAudiences(values: List<Output<String>>) {
        this.allowedAudiences = Output.all(values)
    }

    /**
     * @param value The configuration settings of the default authorization policy.
     */
    @JvmName("ktbsitnkhxnjikwf")
    public suspend fun defaultAuthorizationPolicy(`value`: Output<DefaultAuthorizationPolicyArgs>) {
        this.defaultAuthorizationPolicy = value
    }

    /**
     * @param value The configuration settings of the checks that should be made while validating the JWT Claims.
     */
    @JvmName("akobsunwtgdjrvbj")
    public suspend fun jwtClaimChecks(`value`: Output<JwtClaimChecksArgs>) {
        this.jwtClaimChecks = value
    }

    /**
     * @param value The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("pqmebaxiiypdpakq")
    public suspend fun allowedAudiences(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedAudiences = mapped
    }

    /**
     * @param values The list of audiences that can make successful authentication/authorization requests.
     */
    @JvmName("wmvwxxdwocpjcewk")
    public suspend fun allowedAudiences(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedAudiences = mapped
    }

    /**
     * @param value The configuration settings of the default authorization policy.
     */
    @JvmName("pkigcyuitwjnkgnq")
    public suspend fun defaultAuthorizationPolicy(`value`: DefaultAuthorizationPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultAuthorizationPolicy = mapped
    }

    /**
     * @param argument The configuration settings of the default authorization policy.
     */
    @JvmName("sxmgrjrurjvgsgfx")
    public suspend
    fun defaultAuthorizationPolicy(argument: suspend DefaultAuthorizationPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = DefaultAuthorizationPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.defaultAuthorizationPolicy = mapped
    }

    /**
     * @param value The configuration settings of the checks that should be made while validating the JWT Claims.
     */
    @JvmName("gplhbegpyuoenwyb")
    public suspend fun jwtClaimChecks(`value`: JwtClaimChecksArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.jwtClaimChecks = mapped
    }

    /**
     * @param argument The configuration settings of the checks that should be made while validating the JWT Claims.
     */
    @JvmName("qelgchextindhfvv")
    public suspend fun jwtClaimChecks(argument: suspend JwtClaimChecksArgsBuilder.() -> Unit) {
        val toBeMapped = JwtClaimChecksArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.jwtClaimChecks = mapped
    }

    internal fun build(): AzureActiveDirectoryValidationArgs = AzureActiveDirectoryValidationArgs(
        allowedAudiences = allowedAudiences,
        defaultAuthorizationPolicy = defaultAuthorizationPolicy,
        jwtClaimChecks = jwtClaimChecks,
    )
}
